<?php
/**
 * Class session model
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Model_Session' )) 
{
  /**
   * Class for manage session data
   */
  class IPCht_Model_Session extends IPCht_Model
  {
		/**
		 * Get Sessions
		 *
		 * @return array
		 */
		public function getSessions()
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_sessions';
			$query  = "
					SELECT * FROM $table
					ORDER BY sess_timestamp_gmt DESC
			";
			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get User Sessions
		 *
		 * @return array
		 */
		public function getUserSessions()
		{
			global $wpdb;
			$table1 = $wpdb->prefix . 'ipcht_sessions';
			$table2 = $wpdb->prefix . 'ipcht_users';
			$query  = "
					SELECT DISTINCT * FROM $table1
						JOIN $table2 
							ON $table1.user_id = $table2.user_id
					ORDER BY $table1.sess_last_active_gmt DESC
			";
			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get Session
		 *
		 * @return int   $sessionId
		 * @return array
		 */
		public function getSession( $sessionId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_sessions';
			$query  = "
					SELECT * FROM $table
					WHERE
						sess_id = $sessionId
			";
			$results = $wpdb->get_row( $query, ARRAY_A );
			return $results;
		}

		/**
		 * Get New Session
		 *
		 * @return int   $userId
		 * @return array
		 */
		public function getNewSession( $userId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_sessions';
			$query  = "
					SELECT * FROM $table
					WHERE
						user_id = $userId
					ORDER BY sess_last_active_gmt DESC
			";
			$results = $wpdb->get_row( $query, ARRAY_A );
			return $results;
		}

		/**
		 * Get Session by key
		 *
		 * @return int   $sessionKey
		 * @return array
		 */
		public function getSessionByKey( $sessionKey )
		{
			global $wpdb;
			$table1 = $wpdb->prefix . 'ipcht_sessions';
			$table2 = $wpdb->prefix . 'ipcht_users';
			$query  = "
					SELECT DISTINCT * FROM $table1
						JOIN $table2 
							ON $table1.user_id = $table2.user_id
					WHERE
						$table1.sess_key = '$sessionKey'
			";
			$results = $wpdb->get_row( $query, ARRAY_A );
			return $results;
		}

		/**
		 * Insert Session
		 *
		 * @param  array $data
		 * @param  array $format
		 * @return void
		 */
		public function insertSession( $data, $format = array() )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipcht_sessions';
				$data   = (array)$data;

				$result = $wpdb->insert( $table, $data, $format );
				if ( $result ) {
						return $wpdb->insert_id;
				}
				return false;
		}

		/**
		 * Update Session
		 *
		 * @param  int   $id
		 * @param  array $data
		 * @return void
		 */
		public function updateSession( $id, $data )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipcht_sessions';
				$data   = (array)$data;
				$where  = array(
						'sess_id' => absint( $id )
				);
				$result = $wpdb->update( $table, $data, $where );
				return $result;
		}

		/**
		 * Delete Session
		 *
		 * @param  int   $id
		 * @return void
		 */
		public function deleteSession( $id )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_sessions';
			$where  = array(
					'sess_id' => absint( $id )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}

		/**
		 * Delete Sessions
		 *
		 * @param  int   $userId
		 * @return void
		 */
		public function deleteSessions( $userId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_sessions';
			$where  = array(
					'user_id' => absint( $userId )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}

  }
}