;(function($){    
    //pass in just the context as a $(obj) or a settings JS object
    $.fn.autogrow = function(opts) {
        var that = $(this).css({overflow: 'hidden', resize: 'none'}) //prevent scrollies
            , selector = that.selector
            , defaults = {
                context: $(document) //what to wire events to
                , animate: true //if you want the size change to animate
                , speed: 200 //speed of animation
                , fixMinHeight: true //if you don't want the box to shrink below its initial size
                , cloneClass: 'autogrowclone' //helper CSS class for clone if you need to add special rules
                , onInitialize: false //resizes the textareas when the plugin is initialized
            }
        ;
        opts = $.isPlainObject(opts) ? opts : {context: opts ? opts : $(document)};
        opts = $.extend({}, defaults, opts);
        that.each(function(i, elem){
            var min, clone;
            elem = $(elem);
            //if the element is "invisible", we get an incorrect height value
            //to get correct value, clone and append to the body. 
            if (elem.is(':visible') || parseInt(elem.css('height'), 10) > 0) {
                min = parseInt(elem.css('height'), 10) || elem.innerHeight();
            } else {
                clone = elem.clone()
                    .addClass(opts.cloneClass)
                    .val(elem.val())
                    .css({
                        position: 'absolute'
                        , visibility: 'hidden'
                        , display: 'block'
                    })
                ;
                $('body').append(clone);
                min = clone.innerHeight();
                clone.remove();
            }
            if (opts.fixMinHeight) {
                elem.data('autogrow-start-height', min); //set min height                                
            }
            elem.css('height', min);
            
            if (opts.onInitialize && elem.length) {
                resize.call(elem[0]);
            }
        });
        opts.context
            .on('keyup paste', selector, resize)
        ;
    
        function resize (e){
            var box = $(this)
                , oldHeight = box.innerHeight()
                , newHeight = this.scrollHeight
                , minHeight = box.data('autogrow-start-height') || 0
                , clone
            ;
            if (oldHeight < newHeight) { //user is typing
                this.scrollTop = 0; //try to reduce the top of the content hiding for a second
                if(opts.animate) {
                    box.stop().animate({height: newHeight}, {duration: opts.speed, complete: notifyGrown});
                } else {
                    box.innerHeight(newHeight);
                    notifyGrown();
                }
                
            } else if (!e || e.which == 8 || e.which == 46 || (e.ctrlKey && e.which == 88)) { //user is deleting, backspacing, or cutting
                if (oldHeight > minHeight) { //shrink!
                    //this cloning part is not particularly necessary. however, it helps with animation
                    //since the only way to cleanly calculate where to shrink the box to is to incrementally
                    //reduce the height of the box until the $.innerHeight() and the scrollHeight differ.
                    //doing this on an exact clone to figure out the height first and then applying it to the
                    //actual box makes it look cleaner to the user
                    clone = box.clone()
                        //add clone class for extra css rules
                        .addClass(opts.cloneClass)
                        //make "invisible", remove height restriction potentially imposed by existing CSS
                        .css({position: 'absolute', zIndex:-10, height: ''}) 
                        //populate with content for consistent measuring
                        .val(box.val()) 
                    ;
                    box.after(clone); //append as close to the box as possible for best CSS matching for clone
                    do { //reduce height until they don't match
                        newHeight = clone[0].scrollHeight - 1;
                        clone.innerHeight(newHeight);
                    } while (newHeight === clone[0].scrollHeight);
                    newHeight++; //adding one back eliminates a wiggle on deletion 
                    clone.remove();
                    box.focus(); // Fix issue with Chrome losing focus from the textarea.
                    
                    //if user selects all and deletes or holds down delete til beginning
                    //user could get here and shrink whole box
                    newHeight < minHeight && (newHeight = minHeight);
                    if(oldHeight > newHeight) {
                        if(opts.animate) {
                            box.stop().animate({height: newHeight}, {duration: opts.speed, complete: notifyShrunk});
                        } else {
                            box.innerHeight(newHeight);
                            notifyShrunk();
                        }
                    }
                    
                } else { //just set to the minHeight
                    box.innerHeight(minHeight);
                }
            } 
        }

        // Trigger event to indicate a textarea has grown.
        function notifyGrown() {
            opts.context.trigger('autogrow:grow');
        }

        // Trigger event to indicate a textarea has shrunk.
        function notifyShrunk() {
            opts.context.trigger('autogrow:shrink');
        }

        return that;
    }
})(jQuery);

(function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
var ui = require( './../libs/ui.js' );

(function($)
{
  "use strict";

  //
  //Modal
  var iznModal = 
  {
    open: function( modal, animation )
    {
      $('body').addClass( 'ipcht-scroll-off' );
      $(window).scrollTop(0);
      modal.show();
      modal.velocity({
        opacity: 1,
        duration: 400
      });
      //Show content
      if ( animation == undefined ) {
        animation = 'slideDown';
      }
      var anim = 'transition.' + animation + 'In';
      $( '.ipcht-modal-main', modal ).velocity( anim, {
        duration: 500
      });
      modal.scrollTop(0);
    },
    close: function( modal, animation )
    {
      //Hide content
      if ( animation == undefined ) {
        animation = 'slideDown';
      }
      var anim = 'transition.' + animation + 'Out';
      $( '.ipcht-modal-main', modal ).velocity( animation, {
        duration: 500
      });
      modal.velocity({
        opacity: 0,
        duration: 400,
        complete: function()
        {
          setTimeout( function()
          {
            $('body').removeClass( 'ipcht-scroll-off' );
            $(window).scrollTop(0);
          },300 );

          setTimeout( function()
          {
            modal.hide();
          },1000 );
        }
      });
    },
    prepare: function( modal )
    {
      var $this = this;
      $this.setupModal( modal );

      $(window).resize( function()
      {
        var winHeight = $(window).height();
        modal.height( winHeight );
      });
    },
    setupModal: function( modal )
    {
      modal.show();
      var winHeight     = $(window).height();
      var contentHeight = $( '.ipcht-modal-main', modal ).height();
      var modalOverlay  = $( '.ipcht-modal-overlay', modal );
      modal.height( winHeight );
      modal.hide();

      contentHeight += 200;
      if ( winHeight > contentHeight ) {
        contentHeight = winHeight;
      }
      //$( '.ipcht-modal-inner', modal ).height( contentHeight );
    },
  };

  //
  //Chat Helper
  //
  var ipcht_chatHelper = 
  {
    //
    //Prepare chat widget
    prepare: function( result )
    {
      var form = $( '#ipcht-form-chat' );
      $( '[name="key"]', form ).val( result.key );
      $( '[name="user_name"]', form ).val( result.user_name );
      $( '[name="user_icon_text"]', form ).val( result.user_char );

      //Show content
      $( '.ipcht-widget .ipcht-content-chat .ipcht-chats-list' ).append( result.chat );
      $( '.ipcht-widget .ipcht-content' ).hide();
      $( '.ipcht-widget .ipcht-content-chat' ).show();
      $( '.ipcht-widget .ipcht-widget-main' ).removeClass( 'ipcht-widget-main-online' );
      $( '.ipcht-widget .ipcht-widget-main' ).addClass( 'ipcht-widget-main-chat' );

      this.setupWidget();
      this.actions();
    },
    //
    //Setup widget
    setupWidget: function()
    {
      var mainHeight = $( '.ipcht-widget-main-chat' ).height();
      var formHeight = $( '#ipcht-form-chat' ).height();
      var chatHeight = $( '.ipcht-content-chat .ipcht-chats-list' ).height();
      var areaHeight = mainHeight - formHeight - 30;
      var areaTop    = areaHeight - chatHeight - 10;
      if ( areaTop < 0 ) {
        areaTop = 0;
      }

      $( '.ipcht-content-chat .ipcht-chats-block' ).height( areaHeight );
      $( '.ipcht-content-chat .ipcht-chats-list' ).css( 'padding-top', areaTop + 'px' );

      //set scroll
      var block  = $( '.ipcht-content-chat .ipcht-chats-block' );
      var scroll = block[0].scrollHeight;
      block.scrollTop( scroll );
    },
    //
    //Actions
    actions: function()
    {
      var inProcess = false;
      var lastchats = '';

      setInterval( function()
      {
        if ( ! inProcess )
        {
          inProcess = true;
          var color = $( '#ipcht-form-chat [name="admin_icon_color"]' ).val();
          var date  = $( '.ipcht-chat-system-data' ).attr( 'data-lastdate' );

          $.ajax({
            url: ipcht_ajaxurl+'?doajax=1&ipcht=1&action=public_actions',
            type: "POST",
            data: 'color='+color+'&last_chats='+lastchats+'&last_date='+date,
            dataType: "json",
            success: function ( result ) 
            {
              inProcess = false;

              if ( result.status == 1 ) 
              {
                //
                //Append incoming message
                if ( result.admin_chats )
                {
                  $( '.ipcht-widget .ipcht-content-chat .ipcht-chats-list' ).append( result.admin_chats );
                  //set scroll
                  var block  = $( '.ipcht-widget-main-chat .ipcht-chats-block' );
                  var scroll = block[0].scrollHeight;
                  block.scrollTop( scroll );

                  //Play audio
                  var audio = $( '.ipcht-widget .ipcht-widget-settings .ipcht-audio-new-chat' );
                  if ( audio.length > 0 ) {
                      audio[0].play();
                  }

                  lastchats = result.last_chats;
                }
                if ( result.last_date != '0' ) {
                  $( '.ipcht-chat-system-data' ).attr( 'data-lastdate', result.last_date );
                }
              }
              else
              {
                $( '.ipcht-widget .ipcht-content-chat' ).hide();
                if ( result.admin_status == 1 )
                {
                  $( '.ipcht-widget .ipcht-content-offline' ).hide();
                  $( '.ipcht-widget .ipcht-content-online' ).show();
                } 
                else 
                {
                  $( '.ipcht-widget .ipcht-content-offline' ).show();
                  $( '.ipcht-widget .ipcht-content-online' ).hide();
                }
              }
            }
          });
        }

      }, 5000 ); 
    },
    //
    //Display chat
    displayChat: function( message, type )
    {
      var chat = this.createChat( message, type );
      $( '.ipcht-widget .ipcht-content-chat .ipcht-chats-list' ).append( chat );

      //set scroll
      var block  = $( '.ipcht-widget-main-chat .ipcht-chats-block' );
      var scroll = block[0].scrollHeight;
      block.scrollTop( scroll );

      return chat;
    },
    //
    //Creating chat item
    createChat: function( message, type )
    {
      var wrapper = $( '<div class="ipcht-chat-item"></div>' );
      var inner   = $( '<div class="ipcht-chat-inner ipcht-clearfix"></div>' );
      var icon    = this.createChatIcon( type );
      var top     = this.createChatTop( type );
      var content = this.createChatContent( message );
      var bubble  = $( '<div class="ipcht-chat-bubble"></div>' )
                        .append( 
                          $( '<div class="ipcht-chat-bubble-inner"></div>' )
                            .append( top )
                            .append( content )
                        )
                        .appendTo( 
                          inner
                            .append( icon )
                            .appendTo( wrapper ) 
                        );

      return wrapper;
    },
    //
    //Creating chat icon
    createChatIcon: function( type )
    {
      var form     = $( '#ipcht-form-chat' );
      var iconType = $( '[name="icon_type"]', form ).val();

      if ( type == 'user' ) {
        var color = $( '[name="user_icon_color"]', form ).val();
      } else {
        var color = $( '[name="admin_icon_color"]', form ).val();
      }
      var icon = '';
      if ( iconType == 'name' )
      {
        if ( type == 'user' ) {
          var text = $( '[name="user_icon_text"]', form ).val();
        } else {
          var text = $( '[name="admin_icon_text"]', form ).val();
        }
        icon = '<div class="ipcht-chat-icon ipcht-chat-icon-alpha" style="background-color:'+color+';">' + text + '</div>';
      }
      else
      if ( iconType == 'photo' )
      {
        if ( type == 'user' ) {
          var url = $( '[name="user_icon_url"]', form ).val();
        } else {
          var url = $( '[name="admin_icon_url"]', form ).val();
        }
        icon = '<div class="ipcht-chat-icon ipcht-chat-icon-photo"><img src="' + url + '"></div>';
      }
      else
      {
        icon = '<div class="ipcht-chat-icon ipcht-chat-icon-bg" style="background-color:'+color+';"></div>';
      }
      return $( icon );
    },
    //
    //Creating chat top
    createChatTop: function( type )
    {
      var form = $( '#ipcht-form-chat' );

      if ( type == 'user' ) {
        var name = $( '[name="user_name"]', form ).val();
      } else {
        var name = $( '[name="admin_name"]', form ).val();
      }
      var date = this.getNow();
      
      var top     = $( '<div class="ipcht-chat-top"></div>' );
      var userTop = $( '<div class="ipcht-chat-user"></div>')
                        .append( $( '<strong></strong>' ).append( name ) );

      var status  = $( '<span class="ipcht-chat-status ipcht-chat-status-send"></span>')
                        .append( '<i class="ipcht-fa ipcht-fa-clock-o"></i>' )
                        .append( '<i class="ipcht-fa ipcht-fa-check"></i>' );

      var dateTop = $( '<div class="ipcht-chat-date"></div>')
                        .append( date )
                        .append( status );

      top.append( userTop );
      top.append( dateTop );

      return top;
    },
    //
    //Creating chat content
    createChatContent: function( message )
    {
      var msg = $( '<div class="ipcht-chat-message"></div>' ).append( message );
      return msg;
    },
    //
    //Get date now
    getNow: function()
    {
      var today = new Date();
      var dd    = today.getDate();
      var mm    = today.getMonth()+1;
      var hour  = today.getHours();
      var min   = today.getMinutes();
      if ( hour < 10 ) {
        hour = '0' + hour;
      }
      if ( min < 10 ) {
        min = '0' + min;
      }
      var date  = dd+'/'+mm+' '+hour+':'+min;

      return date;
    }
  }

  $(document).ready(function()
  {
    //
    //Init ui
    ui.base.modal.prototype.top_margin = '20px';
    var modal  = new ui.base.modal();

    ui.base.loader.prototype.image_base  = ipcht_img_url;
    ui.base.loader.prototype.loader_file = 'loading.gif'; 
    var loader  = new ui.base.loader();
    var message = new ui.base.message();

    var winWidth  = $(window).width();
    var winHeight = $(window).height();

    //
    //Auto expand textarea
    //
    if ( $('.ipcht-widget textarea').length > 0 )
    {
      $('.ipcht-widget textarea').autogrow(); 
    }

    //
    //Fixed widget main chat height
    ipcht_chatHelper.actions();
    if ( $( '.ipcht-widget-main-chat' ).length > 0 )
    {
      ipcht_chatHelper.setupWidget();
    }

    //
    //Form offline message
    //
    //name rule
    jQuery.validator.addMethod("validname", function(value, element) {
      return this.optional(element) || /^[a-zA-Z0-9\s]*$/.test(value);
    }, "The value is not valid.");

    jQuery.validator.addMethod("validemail", function(value, element) 
    {
      var re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
      return this.optional(element) || re.test(value);
    }, "Please enter a valid email address.");

    //
    //Form offline validate
    if ( $( '#ipcht-form-offline' ).length > 0 )
    {
      var validateRules = {
        email: {
          required: true,
          validemail: true
        },
        message: {
          required: true
        },
      };

      if ( $( '#ipcht-form-offline .ipcht-field-name' ).length > 0 ) 
      {
        validateRules.name = {
          required: true,
          validname: true
        };
      }

      if ( $( '#ipcht-form-offline .ipcht-field-phone' ).length > 0 ) 
      {
        validateRules.phone = {
          required: true
        };
      }

      $("#ipcht-form-offline").validate(
      {
        ignore: [],
        errorClass: "form-field-error",
        errorElement: "div",
        errorPlacement: function( error, element )
        {
            var field = element.parents( '.form-field' );
            field.addClass( 'form-field-invalid' );
            if ( field.hasClass( 'form-field-inline' )) {
                field.append( error );
            } else {
                element.after( error );
            }
        },
        highlight: function( element, errorClass, validClass )
        {
            $(element)
                .parents( '.form-field' )
                .addClass( 'form-field-invalid' );
        },
        unhighlight: function(element, errorClass, validClass)
        {
          $(element)
              .parents( '.form-field' )
              .removeClass( 'form-field-invalid' );

        },
        focusCleanup: true,
        onkeyup: false,
        rules: validateRules,
        messages: {},
        submitHandler: function(form) 
        {
          showWidgetLoader();

          //Try to set online status
          $.ajax({
            url: ipcht_ajaxurl+'?doajax=1&ipcht=1&action=send_offline_message',
            type: "POST",
            data: $(form).serialize(),
            dataType: "json",
            success: function ( result ) 
            {
              hideWidgetLoader();
              //
              //Show message
              var alertClass = 'ipcht-alert-danger';
              if ( result.status == 1 ) {
                alertClass = 'ipcht-alert-success';
              }
              $( '.ipcht-content-offline .ipcht-form-message .ipcht-alert' ).addClass( alertClass );
              $( '.ipcht-content-offline .ipcht-form-message .ipcht-alert' ).text( result.message );
              $( '.ipcht-content-offline .ipcht-form-message' ).show();
              //
              //Reset form
              $(form)[0].reset();
            }
          });
        }
      });
    };

    //
    //Form online message
    //
    //
    //Form online validate
    if ( $( '#ipcht-form-online' ).length > 0 )
    {
      var validateRules = {
        email: {
          required: true,
          validemail: true
        },
        message: {
          required: true
        },
      };

      if ( $( '#ipcht-form-online .ipcht-field-name' ).length > 0 ) 
      {
        validateRules.name = {
          required: true,
          validname: true
        };
      }

      if ( $( '#ipcht-form-online .ipcht-field-phone' ).length > 0 ) 
      {
        validateRules.phone = {
          required: true
        };
      }

      $("#ipcht-form-online").validate(
      {
        ignore: [],
        errorClass: "form-field-error",
        errorElement: "div",
        errorPlacement: function( error, element )
        {
            var field = element.parents( '.form-field' );
            field.addClass( 'form-field-invalid' );
            if ( field.hasClass( 'form-field-inline' )) {
                field.append( error );
            } else {
                element.after( error );
            }
        },
        highlight: function( element, errorClass, validClass )
        {
            $(element)
                .parents( '.form-field' )
                .addClass( 'form-field-invalid' );
        },
        unhighlight: function(element, errorClass, validClass)
        {
          $(element)
              .parents( '.form-field' )
              .removeClass( 'form-field-invalid' );

        },
        focusCleanup: true,
        onkeyup: false,
        rules: validateRules,
        messages: {},
        submitHandler: function(form) 
        {
          showWidgetLoader();

          //Try to set online status
          $.ajax({
            url: ipcht_ajaxurl+'?doajax=1&ipcht=1&action=start_chat&type=guest',
            type: "POST",
            data: $(form).serialize(),
            dataType: "json",
            success: function ( result ) 
            {
              //Offline
              if ( result.type == 'offline' )
              {
                //
                //Show message
                var alertClass = 'ipcht-alert-danger';
                if ( result.status == 1 ) {
                  alertClass = 'ipcht-alert-success';
                }
                $( '.ipcht-content-online .ipcht-form-message .ipcht-alert' ).addClass( alertClass );
                $( '.ipcht-content-online .ipcht-form-message .ipcht-alert' ).text( result.message );
                $( '.ipcht-content-online .ipcht-form-message' ).show();
                $( '.ipcht-content-online .ipcht-form-message-off .ipcht-alert' ).text( result.messageOff );
                $( '.ipcht-content-online .ipcht-form-message-off' ).show();
                //
                //Reset form
                $(form)[0].reset();
                //Hide loader
                hideWidgetLoader();
              }
              //Online
              else if ( result.type == 'online' )
              {
                if ( result.status == 1 )
                {
                  //Prepare chat
                  ipcht_chatHelper.prepare( result );
                }
                else
                {
                  //
                  //Show message
                  var alertClass = 'ipcht-alert-danger';
                  $( '.ipcht-content-online .ipcht-form-message .ipcht-alert' ).addClass( alertClass );
                  $( '.ipcht-content-online .ipcht-form-message .ipcht-alert' ).text( result.message );
                  $( '.ipcht-content-online .ipcht-form-message' ).show();
                }
                //Hide loader
                hideWidgetLoader();
              }
            }
          });
        }
      });
    };

    //
    //Form chat
    //
    //
    //Form chat validate
    if ( $( '#ipcht-form-chat' ).length > 0 )
    {
      var validateRules = {
        message: {
          required: true
        }
      };

      $("#ipcht-form-chat").validate(
      {
        ignore: [],
        errorClass: "form-field-error",
        errorElement: "div",
        errorPlacement: function( error, element )
        {
          var field = element.parents( '.form-field' );
          field.addClass( 'form-field-invalid' );
          if ( field.hasClass( 'form-field-inline' )) {
              field.append( error );
          } else {
              element.after( error );
          }
        },
        highlight: function( element, errorClass, validClass )
        {
          $(element)
              .parents( '.form-field' )
              .addClass( 'form-field-invalid' );
        },
        unhighlight: function(element, errorClass, validClass)
        {
          $(element)
              .parents( '.form-field' )
              .removeClass( 'form-field-invalid' );

        },
        focusCleanup: true,
        onkeyup: false,
        rules: validateRules,
        messages: {},
        submitHandler: function(form) 
        {
          var $form   = $(form);
          var message = $( '[name="message"]', $form ).val();
          var chat    = ipcht_chatHelper.displayChat( message, 'user' );

          //Play audio
          var audio = $( '.ipcht-widget .ipcht-widget-settings .ipcht-audio-sending' );
          if ( audio.length > 0 ) {
            audio[0].play();
          }

          //Send chat
          $.ajax({
            url: ipcht_ajaxurl+'?doajax=1&ipcht=1&action=send_chat&type=user',
            type: "POST",
            data: $(form).serialize(),
            dataType: "json",
            success: function ( result ) 
            {
              //
              //Reset form
              $form[0].reset();

              if ( result.status == 1 )
              {
                chat.find( '.ipcht-chat-status' )
                    .removeClass( 'ipcht-chat-status-send' )
                    .addClass( 'ipcht-chat-status-delivered' );
              }
            }
          });
        }
      });
    };

    //
    //Widget actions
    //
    var ipchtAnimType  = $( '.ipcht-settings-visibilty' ).data( 'animation' );
    var ipchtAnimSpeed = $( '.ipcht-settings-visibilty' ).data( 'speed' );
    if ( ipchtAnimType === undefined ) {
      ipchtAnimType = 'none';
    }
    var ipchtEasing  = ipcht_getEasing( ipchtAnimType );
    if ( ipchtAnimSpeed === undefined ) {
      ipchtAnimSpeed = 500;
    }
    var ipchtAnimAttr = {
      queue:false, 
      duration:ipchtAnimSpeed, 
      easing:ipchtEasing
    };

    //minimize
    $( '.ipcht-action-minimize a' ).click( function()
    {
      var wrapper = $(this).parents( '.ipcht-widget-wrapper' );
      var widget  = $(this).parents( '.ipcht-widget' );
      var tab     = $( '.ipcht-widget-tab', wrapper );

      /*if ( wrapper.hasClass( 'ipcht-widget-show') )
      {
        wrapper.removeClass( 'ipcht-widget-show' );
        wrapper.addClass( 'ipcht-widget-hide' );
        widget.removeClass( 'ipcht-open' );
        tab.addClass( 'ipcht-open' );
      } else
      {
        wrapper.removeClass( 'ipcht-widget-hide' );
        wrapper.addClass( 'ipcht-widget-show' );
        widget.addClass( 'ipcht-open' );
        tab.removeClass( 'ipcht-open' );
      }*/

      wrapper.removeClass( 'ipcht-widget-show' );
      wrapper.addClass( 'ipcht-widget-hide' );

      widget.animate({
        bottom: '-120%'
      }, ipchtAnimAttr );

      tab.animate({
        bottom: '0'
      }, ipchtAnimAttr );

      return false;
    });

    //open chat widget
    $( '.ipcht-tab-button .ipcht-button' ).click( function()
    {
      var wrapper = $(this).parents( '.ipcht-widget-wrapper' );
      var tab     = $(this).parents( '.ipcht-widget-tab' );
      var widget  = $( '.ipcht-widget', wrapper );

      wrapper.removeClass( 'ipcht-widget-hide' );
      wrapper.addClass( 'ipcht-widget-show' );

      widget.animate({
        bottom: '0'
      }, ipchtAnimAttr );

      tab.animate({
        bottom: '-120%'
      }, ipchtAnimAttr );

      return false;
    });

    //
    //Get animation easing
    function ipcht_getEasing( effect )
    {
      if ( effect == 'bounce' ) {
          var easing = 'easeOutBounce';
      } else if ( effect == 'back' ) {
          var easing = 'easeOutBack';
      } else if ( effect == 'elastic' ) {
          var easing = 'easeOutElastic';
      } else if ( effect == 'expo' ) { 
          var easing = 'easeOutExpo';
      } else {
          var easing = 'linear';
      }
      return easing;
    };

    //
    //Show widget loader
    function showWidgetLoader()
    { 
      $( '.ipcht-widget-content' ).animate({
        'opacity': 0
      }, 600 );

      $( '.ipcht-main-loader' ).css( 'opacity', 0 );
      $( '.ipcht-main-loader' ).show();

      $( '.ipcht-main-loader' ).animate({
        'opacity': 1
      }, 600 );
    }

    //
    //Hide widget loader
    function hideWidgetLoader()
    { 
      $( '.ipcht-widget-content' ).animate({
        'opacity': 1
      }, 600 );

      $( '.ipcht-main-loader' ).animate({
        'opacity': 0
      }, 600, function(){
        $( '.ipcht-main-loader' ).hide();
      } );
    }


  });
})(jQuery);

},{"./../libs/ui.js":2}],2:[function(require,module,exports){
/*
 *===========================================================
 * UI
 *===========================================================
 */
var ui;

(function($)
{
    "use strict";

    //Inherit function
    function inherit( proto )
    {
        function F() {}
        F.prototype = proto
        return new F
    }

    /*
     *===========================================================
     * Ui prototype
     *===========================================================*/
    function ui_construct( options ){};

    ui_construct.prototype =
    {

        vars:               {},
        class_prefix:       'ipcht-',
        class_main:         '-main',
        class_title:        '-title',
        class_content:      '-content',
        class_disabled:     'disabled',
        class_close:        'ui-close',
        label_close:        'x',
        image_base:         '',

        top_margin:         '80px',
        overlay_speed:      600,
        main_speed:         400,
        show_speed:         4000,

        show_after:         function(){},
        hide_after:         function(){},

        popup_body: function( class_root, content, title, close )
        {
            var body = $( '<div class="'+class_root+'"></div>' );
            var main = $( '<div class="'+class_root + this.class_main+'"></div>' );
            if ( title )
            {
                var _title = $( '<div class="'+class_root + this.class_title+'"></div>' )
                                .append( '<h3>'+title+'</h3>' );
                if ( close )
                {
                    var _close = $( '<a href="#">'+this.label_close+'</a>' );
                    this.popup_close( _close, class_root );

                    _title.append(
                        $( '<div class="'+this.class_prefix+this.class_close+'"></div>' ).append( _close )
                    );
                }
                main.append( _title );
            }
            if ( content ) {
                main.append(
                    $( '<div class="'+class_root + this.class_content+'"></div>' ).append( content )
                );
            }
            body.append( main );
            return body;
        },
        popup_show: function( popup )
        {
            var c_root = popup.attr( 'class' );
            var main   = $( '.'+c_root+this.class_main, popup );
            popup.show();
            main.css( 'margin-top', '-40%' )
                .animate({marginTop: this.top_margin}, this.main_speed, this.show_after);
        },
        popup_hide: function( popup )
        {
            var c_root = popup.attr( 'class' );
            var main   = $( '.'+c_root+this.class_main, popup );

            popup.animate( {opacity: 0}, this.overlay_speed, function(){
                $(this).css( 'opacity', 1 )
                       .hide();
            });
            main.animate( {marginTop: '-60%'}, this.main_speed, this.hide_after);
        },
        popup_close: function( button, class_popup )
        {
            var ui = this;
            button.click( function(){
                var popup = $( '.'+class_popup );
                ui.popup_hide( popup );
                return false;
            });
        },
        is_load: function( selector )
        {
            if ( $( selector ).length > 0 ) {
                return true;
            }
            return false;
        },
        set_vars: function( options )
        {
            this.vars = $.extend(this.vars, options);
        },
        set_base_vars: function( options )
        {
            this.vars = $.extend(this, options);
        },
        go_to: function( selector )
        {
            var pos = $( selector ).position();
            $('html, body').animate({scrollTop: ( pos.top )}, 600);
            return false;
        }
    };

    /*
     * Modal Class
     **/
    function modal(){};
    modal.prototype = inherit( ui_construct.prototype );
    //Modal message
    modal.prototype.ajax = function( id, url )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_modal;
        var modal   = this.popup_body( c_root, '', false, false ).appendTo( $( 'body' ) );
        modal.addClass( class_type )
             .attr( 'id', id );

        this.popup_show( modal );
    };

    /*
     * Loader Class
     **/
    function loader(){};
    loader.prototype = inherit( ui_construct.prototype );
    //Properties
    loader.prototype.class_root     = 'ui-loader';
    loader.prototype.loader_file    = 'loading.gif';
    //Show loader
    loader.prototype.show = function()
    {
        var loader = this.create();
        this.popup_show( loader );
    };
    //Hide loader
    loader.prototype.hide = function()
    {
        var loader = this.create();
        this.popup_hide( loader );
    };
    //Create loader
    loader.prototype.create = function()
    {
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            return $( '.'+c_root );
        } else
        {
            var image  = '<img src="'+this.image_base+this.loader_file+'" alt="Loading...">';
            var loader = this.popup_body( c_root, image, false, false ).appendTo( $( 'body' ) );
            loader.hide();

            return loader;
        }
    };


    /*
     * Inline loader Class
     **/
    function iloader(){};
    iloader.prototype = inherit( ui_construct.prototype );
    //Properties
    iloader.prototype.class_root   = 'ui-inline-loader';
    iloader.prototype.loader_file  = 'spin.gif';
    //Loader show
    iloader.prototype.show = function( button )
    {
        button.attr( 'disabled', 'disabled' );
        this.create( button ).show();
    };
    //Loader hide
    iloader.prototype.hide = function( button )
    {
        button.removeAttr( 'disabled' );
        this.create( button ).hide();
    };
    //Creating loader
    iloader.prototype.create = function( button )
    {
        var root   = button.parent();
        var lclass = this.class_prefix + this.class_root;
        if ( $( '.'+lclass, root ).length > 0 ) {
            var loader = $( '.'+lclass, root );
        } else {
            var image  = '<img src="'+this.image_base+this.loader_file+'" alt="Loading...">';
            var loader = $( '<span class="'+lclass+'"></span>' )
                            .append( image )
                            .css( 'margin-left', '8px' );
        }
        button.after( loader );
        return loader;
    };


    /*
     * Confirm popup
     **/
    function confirm( options )
    {
        var defaults = {
            title:      'Confirmation',
            info:       '',
            yes_label:  'Yes',
            no_label:   'Cancel',
            yes_class:  'btn btn-danger',
            no_class:   'btn btn-success',
            action:     function( object ){}
        };
        this.vars = $.extend(defaults, options);
    };
    confirm.prototype = inherit( ui_construct.prototype );
    //Properties
    confirm.prototype.class_root = 'ui-confirm';
    //Confirm show
    confirm.prototype.show = function( object )
    {
        var confirm = this.create( object );
        this.popup_show( confirm );
    };
    //Confirm hide
    confirm.prototype.hide = function( object )
    {
        var confirm = this.create( object );
        this.popup_hide( confirm );
    };
    //Creating confirm
    confirm.prototype.create = function( object )
    {
        var ui     = this;
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            $( '.'+c_root ).remove();
        }
        //Create confirm
        var yesbtn = $( '<a href="#" class="ip-confirm-yes '+this.vars.yes_class+'">'+this.vars.yes_label+'</a>' );
        var nobtn  = $( '<a href="#" class="ip-confirm-no '+this.vars.no_class+'">'+this.vars.no_label+'</a>' );

        yesbtn.click( function(){
            ui.vars.action( object, ui );
            return false;
        });
        this.popup_close( nobtn, c_root );

        var content = $( '<div class="'+c_root+'-inner"></div>' )
            .append( '<p>'+this.vars.info+'</p>' )
            .append(
                $( '<div class="'+c_root+'-actions"></div>' )
                    .append( yesbtn )
                    .append( nobtn )
            );

        var confirm = this.popup_body( c_root, content, this.vars.title, false ).appendTo( $( 'body' ) );
        confirm.hide();

        return confirm;
    };


    /*
     * Alert popup
     **/
    function alert( options )
    {
        var defaults = {
            message:        '',
            label_button:   'Ok',
            class_root:     '',
            class_button:   'ipcht-btn ipcht-btn-sm ipcht-btn-danger',
            after:          function(){}
        };
        this.vars = $.extend(defaults, options);
    };
    alert.prototype = inherit( ui_construct.prototype );
    //Properties
    alert.prototype.class_root = 'ui-alert';
    //Alert show
    alert.prototype.show = function( message )
    {
        this.vars.message = message;
        var alert = this.create();
        this.popup_show( alert );
    };
    //Alert hide
    alert.prototype.hide = function()
    {
        var alert = this.create();
        this.hide_after = this.vars.after;
        this.popup_hide( alert );
    };
    //Creating alert
    alert.prototype.create = function()
    {
        var ui     = this;
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            return $( '.'+c_root );
        } else
        {
            var button = $( '<a href="#" class="'+this.vars.class_button+'">'+this.vars.label_button+'</a>' );
            this.popup_close( button, c_root );

            var c_info  = c_root + '-inner';
            if ( this.vars.class_root != '' ) {
                c_info += ' ' + this.vars.class_root;
            }
            var content = $( '<div class="'+c_info+'"></div>' )
                .append( '<p>'+this.vars.message+'</p>' )
                .append(
                    $( '<div class="'+c_root+'-actions"></div>' )
                        .append( button )
                );

            var popup  = this.popup_body( c_root, content, false, false ).appendTo( $( 'body' ) );
            popup.hide();

            return popup;
        }
    };


    /*
     * Message
     **/
    function message(){};
    message.prototype = inherit( ui_construct.prototype );
    //Properties
    message.prototype.class_modal = 'ui-modal-message';
    message.prototype.class_block = 'ui-message';
    //Modal message
    message.prototype.modal = function( message, class_type )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_modal;
        var content = '<p>'+message+'</p>';
        var msg     = this.popup_body( c_root, content, false, false ).appendTo( $( 'body' ) );
        msg.addClass( class_type )
           .show()
           .animate({top: "0"}, ui.overlay_speed, function(){
                var object = $( this );
                setTimeout( function(){
                    object.animate({top: '-100px'}, ui.overlay_speed, function(){
                        object.remove();
                    });
                }, ui.show_speed);
            });
    };
    //Bloack message
    message.prototype.block = function( message, class_type, block, close )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_block;
        var parent  = block.parent();

        $( '.'+c_root, parent ).remove();

        var msg = $( '<div></div>' );
        msg.addClass( c_root )
           .addClass( class_type )
           .append( '<p>'+message+'</p>' );

        if ( close )
        {
            var _close = $( '<a href="#">'+this.close_label+'</a>' );
            _close.click( function()
            {
                var _msg = $(this).parents( '.'+c_root );
                _msg.animate({opacity: "0"}, ui.overlay_speed, function(){
                    _msg.remove();
                });
                return false;
            });
            msg.append(
                $( '<div class="'+this.class_prefix+this.class_close+'"></div>' ).append( _close )
            );
        }
        msg.css( 'opacity', '0' );
        parent.prepend( msg );
        msg.animate({opacity: "1"}, ui.overlay_speed);
    };

    ui =
    {
        base: {
            construct:  ui_construct,
            loader:     loader,
            iloader:    iloader,
            confirm:    confirm,
            message:    message,
            alert:      alert,
            modal:      modal

        },
        init: function()
        {
            this.loader  = new this.base.loader(),
            this.iloader = new this.base.iloader(),
            this.confirm = new this.base.confirm(),
            this.message = new this.base.message(),
            this.alert   = new this.base.alert(),
            this.modal   = new this.base.modal()
        }
    };

})(jQuery);

module.exports = ui;

},{}]},{},[1]);
